package cn.com.victorysoft.business.indicator.dao;

import cn.com.victorysoft.business.indicator.entity.SectionRateSummary;
import cn.com.victorysoft.business.indicator.param.RangeWellType;
import cn.com.victorysoft.business.indicator.param.SectionRateSummaryParam;
import cn.com.victorysoft.business.indicator.param.WellSectionMonthParam;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;

import java.util.List;

@Mapper
public interface SectionRateSummaryDao {

    int insert(SectionRateSummary record);

    List<SectionRateSummary> selectUnitChildren(WellSectionMonthParam param);

    List<SectionRateSummary> selectRange(WellSectionMonthParam param);

    List<SectionRateSummary> summaryByInjectType(WellSectionMonthParam param);

    List<SectionRateSummary> summarySingle(WellSectionMonthParam param);

    List<SectionRateSummary> summaryBlock(WellSectionMonthParam param);

    List<SectionRateSummary> summarySplit(WellSectionMonthParam param);

    int deleteByMonth(String month);

    /**
     * 汇总站级数据
     */
    void summary(@Param("month") String month, @Param("unitColumn") String unitColumn);
}
